
# Les imports nécessaires
import sys
from astropy.io.fits import getheader
from astropy import time, coordinates as coord, units as u
from astropy.wcs import WCS
from astroquery.simbad import Simbad

# Passage d'argument (ici un nom d'image FITS, le même, mais...)
img_name = sys.argv[1]
head = getheader(img_name)
wcs_img = WCS(head)

# Jouons avec quelques points remarquables
img_centre = coord.SkyCoord(ra=head['CRVAL1'] * u.deg, dec=head['CRVAL2'] * u.deg)
pix_x = [1, 1, head['NAXIS1'], head['NAXIS1']]
pix_y = [1, head['NAXIS2'], 1, head['NAXIS2']]
angl_coord = wcs_img.pixel_to_world(pix_x, pix_y)

# On peut calculer des distances
dist_x = angl_coord[2].separation(angl_coord[0])
dist_y = angl_coord[1].separation(angl_coord[0])
field_img = dist_x * dist_y

# Les mêmes en arcmin
dist_x_arcmin = dist_x.to(u.arcmin)
dist_y_arcmin = dist_y.to(u.arcmin)
field_img_min2 = dist_x_arcmin * dist_y_arcmin

ratio = field_img_min2 / field_img
arc_min2 = u.arcmin * u.arcmin
diff = field_img_min2 - field_img.to(arc_min2)

# Back to pixels
angl_pix_ra, ang_pix_dec = [], []
angl_pix_ra.append(angl_coord.ra[0])
angl_pix_ra.append(angl_coord.ra[-1])
ang_pix_dec.append(angl_coord.dec[0])
ang_pix_dec.append(angl_coord.dec[-1])

img_angl = coord.SkyCoord(ra=angl_pix_ra, dec=ang_pix_dec)
img_pix = wcs_img.world_to_pixel(img_angl)

diff_x1 = 1 - img_pix[0][0]
diff_x2 = head['NAXIS1'] - img_pix[0][-1]
diff_y1 = 1 - img_pix[1][0]
diff_y2 = head['NAXIS2'] - img_pix[1][-1]

# Et en coordonnées galactiques ?
gal_coord = angl_coord.galactic

# Qu'est-ce qu'on a sur l'image qui serait connu dans Simbad ?
obj_in_img = Simbad.query_region(img_centre, radius=max(dist_x, dist_y) / 2.0)
obj_coord = coord.SkyCoord(ra=obj_in_img['RA'], dec=obj_in_img['DEC'], unit=(u.hourangle, u.deg))
obj_in_img['RA'], obj_in_img['DEC'] = obj_coord.ra, obj_coord.dec

# Il faut resauver le soldat Ry..., euh, la table des objets Simbad
obj_in_img.write('ObjectsInImg.csv', format='ascii.csv', overwrite=True)

# "One more thing..." : helicoentric correction. Ca dépend aussi du site d'observation
site_coord = coord.EarthLocation(lon=head['SITELONG'] * u.deg, lat=head['SITELAT'] * u.deg)
date_obs = time.Time(head['DATE-OBS'], location=site_coord)
helio_corr = date_obs.light_travel_time(img_centre).to(u.min)

print('Process completed')
exit(0)
